@@ -1,5 +1,5 @@
 package Test::Portability::Files;
-$Test::Portability::Files::VERSION = '0.07';
+$Test::Portability::Files::VERSION = '0.09';
 # ABSTRACT: Check file names portability
 use strict;
 use warnings;
@@ -46,6 +46,7 @@ my %tests = (
     dos_length    => 0,
     case          => 1,
     'symlink'     => 1,
+    windows_reserved => 1,
 );
 
 my %errors_text =
@@ -148,6 +149,12 @@ sub test_name_portability {
         /^[A-Za-z0-9._][A-Za-z0-9._-]*$/ or $bad_names{$file} .= 'ansi_chars,';
     }
 
+    # check if the name is a Windows Reserved Filename
+    if ( $tests{'windows_reserved'} ) {
+        $file_name =~ /^(CON|PRN|AUX|NUL|COM[1-9]|LPT[1-9])$/i
+            and $bad_names{$file} .= 'windows_reserved,';
+    }
+
     # check if the name contains more than one dot
     if ( $tests{one_dot} ) {
         tr/.// > 1 and $bad_names{$file} .= 'one_dot,';
@@ -225,12 +232,13 @@ sub run_tests {
     }
 
     # check the results
-    if ( keys %bad_names ) {
+    my $bad_names = _bad_names();
+    if ( keys %$bad_names ) {
         $Test->ok( 0, "File names portability" );
 
         my %errors_list = ();
-        for my $file ( keys %bad_names ) {
-            for my $error ( split ',', $bad_names{$file} ) {
+        for my $file ( keys %$bad_names ) {
+            for my $error ( split ',', $bad_names->{$file} ) {
                 $errors_list{$error} = [] if not ref $errors_list{$error};
                 push @{ $errors_list{$error} }, $file;
             }
@@ -252,6 +260,11 @@ sub run_tests {
 }
 
 
+sub _bad_names {
+    return \%bad_names;
+}
+
+
 1;
 
 __END__
@@ -266,7 +279,7 @@ Test::Portability::Files - Check file names portability
 
 =head1 VERSION
 
-version 0.07
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -342,6 +355,10 @@ C<test_symlink> is enabled
 
 C<test_vms_length> is enabled
 
+=item *
+
+C<windows_reserved> is enabled
+
 =back
 
 To change any option, please see C<options()>.
@@ -486,7 +503,7 @@ Alexander Hartmaier <abraxxa@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Sébastien Aperghis-Tramoni, Alexander Hartmaier.
+This software is copyright (c) 2017 by Sébastien Aperghis-Tramoni, Alexander Hartmaier.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
